summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttree.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttree.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttree.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttree.h b/kmymoney2/widgets/kmymoneyaccounttree.h
index c879fef..9b808b3 100644
--- a/kmymoney2/widgets/kmymoneyaccounttree.h
+++ b/kmymoney2/widgets/kmymoneyaccounttree.h
@@ -43,27 +43,27 @@ public:
* Constructor to be used to construct an institution entry
* object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
* the KListView entry is constructed
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyInstitution& institution);
+ KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyInstitution& institution);
/**
* Constructor to be used to construct a standard account entry object (e.g. Asset,
* Liability, etc.).
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
/**
* Constructor to be used to construct an account entry
@@ -72,7 +72,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks
* @param security const reference to the security used to show the value. Usually
@@ -43,27 +43,27 @@ public:
* object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
@@ -43,27 +43,27 @@ public:
* added to.
* @param institution const reference to MyMoneyInstitution for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
*/
@@ -43,27 +43,27 @@ public:
* Liability, etc.).
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -43,27 +43,27 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
@@ -72,7 +72,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks